@@ -29,6 +29,7 @@ from defusedxml import minidom
 from eodatasets3 import DatasetDoc, DatasetPrepare, serialise
 from eodatasets3.properties import Eo3Interface
 from eodatasets3.ui import PathPath
+from eodatasets3.utils import pass_config
 
 # Static namespace to generate uuids for datacube indexing
 S2_UUID_NAMESPACE = uuid.UUID("9df23adf-fc90-4ec7-9299-57bd536c7590")
@@ -191,7 +192,7 @@ def prepare_and_write(
 ) -> Tuple[DatasetDoc, Path]:
     if embed_location is None:
         # Default to embedding the location if they're not in the same folder.
-        embed_location = dataset_location.parent != output_yaml.parent
+        embed_location = output_yaml.parent not in dataset_location.parents
         _LOG.debug(
             "Auto-embed location? %s: %s %s %s",
             "Yes" if embed_location else "No",
@@ -494,8 +495,6 @@ class Job:
     required=False,
     type=YearMonth(),
 )
-@environment_option
-@config_option
 @click.option(
     "--index",
     "index_to_odc",
@@ -509,7 +508,11 @@ class Job:
     is_flag=True,
     default=False,
 )
+@environment_option
+@config_option
+@pass_config(required=False)
 def main(
+    local_config: LocalConfig,
     output_base: Optional[Path],
     input_relative_to: Optional[Path],
     datasets: Tuple[Path],
@@ -524,7 +527,6 @@ def main(
     after_month: Optional[Tuple[int, int]],
     dry_run: bool,
     index_to_odc: bool,
-    local_config: LocalConfig = None,
 ):
     if sys.argv[1] == "sentinel-l1c":
         warnings.warn(
@@ -541,22 +543,12 @@ def main(
     if datasets_path:
         datasets = [
             *datasets,
-            *(Path(p.strip()) for p in (datasets_path.read_text().splitlines())),
+            *(
+                normalise_path(p.strip())
+                for p in (datasets_path.read_text().splitlines())
+            ),
         ]
 
-    # The default input_relative path is a parent folder named 'L1C'.
-    if output_base and input_relative_to is None and datasets:
-        for parent in datasets[0].parents:
-            if parent.name.lower() == "l1c":
-                input_relative_to = parent
-                break
-        else:
-            raise ValueError(
-                "Unknown root folder for path subfolders. "
-                "(Hint: specify --input-relative-to with a parent folder of the inputs. "
-                "Outputs will use the same subfolder structure.)"
-            )
-
     _LOG.info(f"{len(datasets)} paths(s) to process using {workers} worker(s))")
 
     def files_in_path(input_path: Path):
@@ -571,8 +563,8 @@ def main(
                     "sinergise.com",
                     # Dataset location is the metadata file itself.
                     p,
-                    # Output is an inner metadata file, with the same name as the folder (usually S2A....).
-                    (p.parent / f"{p.parent.stem}.odc-metadata.yaml"),
+                    # Output is a sibling metadata file, with the same name as the folder (usually S2A....).
+                    (p.parent.parent / f"{p.parent.stem}.odc-metadata.yaml"),
                 )
         if provider == "esa.int" or not provider:
             for p in _rglob_with_self(input_path, "*.zip"):
@@ -591,14 +583,14 @@ def main(
             )
 
     def find_jobs() -> Iterable[Job]:
+        nonlocal input_relative_to
         with click.progressbar(
             datasets, label="Preparing metadata", show_pos=True
         ) as progress:
             for i, input_path in enumerate(progress):
-                input_path = normalise_path(input_path)
 
                 first = True
-                for producer, ds_path, output_yaml in files_in_path(input_path):
+                for producer, ds_path, sibling_yaml_path in files_in_path(input_path):
                     # Make sure we tick progress on extra datasets that were found.
                     if not first:
                         progress.length += 1
@@ -643,16 +635,23 @@ def main(
                                 )
                                 continue
 
+                    # Put it in a different folder?
                     if output_base:
-                        output_folder = normalise_path(output_base)
-                        # If we want to copy the input folder hierarchy
-                        if input_relative_to:
-                            output_folder = (
-                                output_folder
-                                / input_path.parent.relative_to(input_relative_to)
+
+                        # What base folder should we choose for creating subfolders in the output?
+                        if input_relative_to is None:
+                            input_relative_to = _get_default_relative_folder_base(
+                                sibling_yaml_path
                             )
 
-                        output_yaml = output_folder / output_yaml.name
+                        output_folder = (
+                            output_base
+                            / sibling_yaml_path.parent.relative_to(input_relative_to)
+                        )
+
+                        output_yaml = output_folder / sibling_yaml_path.name
+                    else:
+                        output_yaml = sibling_yaml_path
 
                     if output_yaml.exists():
                         if not overwrite_existing:
@@ -748,6 +747,22 @@ def main(
     sys.exit(errors)
 
 
+def _get_default_relative_folder_base(path: Path) -> Optional[Path]:
+    for parent in path.parents:
+        if parent.name.lower() == "l1c":
+            input_relative_to = parent
+            _LOG.debug(f"Inputs will be relative to {input_relative_to}")
+            break
+    else:
+        raise ValueError(
+            "Unknown root folder for path subfolders. "
+            "(Hint: specify --input-relative-to with a parent folder of the inputs. "
+            "Outputs will use the same subfolder structure.)"
+        )
+
+    return input_relative_to
+
+
 def _write_dataset_safe(job: Job) -> Union[Tuple[DatasetDoc, Path], str]:
     """
     A wrapper around `prepare_and_write` that catches exceptions and makes them
